@@ -5,7 +5,7 @@ using namespace std;
 struct VI                               // define the data structure to
 {                                       // operate on
     static size_t s_count;
-    typedef int value_type;
+    using value_type = int;
 
     VI() = default;
 
