@@ -4,7 +4,7 @@
     class Base
     {
         public:
-            void member();
+            virtual void member();
     };
     template <typename T>
     void Base<T>::member()
@@ -21,7 +21,7 @@
     {
         public:
             Derived();
-            virtual void member();
+            void member() override;
     };
     template <typename T>
     void Derived<T>::member()
