@@ -11,20 +11,20 @@ struct BinExpr;
 template<typename Type>
 struct BasicType
 {
-    typedef Type ObjType;
+    using ObjType = Type;
 };
 
 template<typename LHS, typename RHS, template<typename> class Operation>
 struct BasicType<BinExpr<LHS, RHS, Operation>>
 {
-    typedef typename BinExpr<LHS, RHS, Operation>::ObjType ObjType;
+    using ObjType = typename BinExpr<LHS, RHS, Operation>::ObjType;
 };
 
 template<typename LHS, typename RHS, template <typename> class  Operation>
 struct BinExpr
 {
-    typedef typename BasicType<RHS>::ObjType ObjType;
-    typedef typename ObjType::value_type value_type;
+    using ObjType = typename BasicType<RHS>::ObjType;
+    using value_type = typename ObjType::value_type;
 
     LHS const &d_lhs;
     RHS const &d_rhs;
@@ -77,6 +77,12 @@ struct VI: public vector<int>
 
 int main(int argc, char **argv)
 {
+    if (argc == 1)
+    {
+        cout << "arg1: number of iterations\n";
+        return 0;
+    }
+
     VI a, b, c, d;
 
     for (size_t idx = 0, count = stoul(argv[1]); idx != count; ++idx)
