@@ -8,7 +8,7 @@ using namespace std;
 int main()
 {
 //EXAMPLE
-    typedef TypeList<int, char, bool> list3;
+    using list3 = TypeList<int, char, bool>;
 
 //    TypeAt<3, list3>::Type invalid;
     TypeAt<0, list3>::Type intVariable = 13;
