@@ -7,7 +7,7 @@
             *d_finish,
             *d_end_of_storage;
         public:
-            typedef reverse_iter<Type> reverse_iterator;
+            using reverse_iterator = reverse_iter<Type>;
 
             Vector();
             Vector(size_t n);
