@@ -25,14 +25,14 @@ class Fibo
     };
     // State ENDS
 
-    typedef std::coroutine_handle<State> Handle;
+    using Handle = std::coroutine_handle<State>;
 public:
     Handle d_handle;
 
     // to access the State, call d_handle.promise()     <<<<<<<<<
 
     public:
-        typedef State promise_type;
+        using promise_type = State;
 
         explicit Fibo(std::coroutine_handle<State> handle);
         ~Fibo();
