@@ -27,7 +27,7 @@ class Fibo
     std::coroutine_handle<State> d_handle;
 
     public:
-        typedef State promise_type;
+        using promise_type = State;
 
         explicit Fibo(std::coroutine_handle<State> handle);
         ~Fibo();
