@@ -4,14 +4,11 @@
     #include <iostream>
     using namespace std;
 
-    class Twice
+    bool twice(size_t first, size_t second)
     {
-        public:
-            bool operator()(size_t first, size_t second) const
-            {
-                return first == (second << 1);
-            }
-    };
+        return first == (second << 1);
+    }
+
     int main()
     {
         string sarr[] =
@@ -27,27 +24,25 @@
                 "golf",
                 "hotel"
             };
-        string  *last = sarr + sizeof(sarr) / sizeof(string);
+        auto past = end(sarr);
 
         copy
         (
-            find_end(sarr, last, search, search + 3),   // sequence starting
-            last, ostream_iterator<string>{ cout, " " } // at 2nd 'foxtrot'
+            find_end(sarr, past, search, search + 3),   // sequence starting
+            past, ostream_iterator<string>{ cout, " " } // at 2nd 'foxtrot'
         );
         cout << '\n';
 
-        size_t range[] = {2, 4, 6, 8, 10, 4, 6, 8, 10};
-        size_t nrs[]   = {2, 3, 4};
+        size_t range[] = { 2, 4, 6, 8, 10, 4, 6, 8, 10 };
+        size_t nrs[]   = { 2, 3, 4 };
 
         copy                // sequence of values starting at last sequence
         (                   // of range[] that are twice the values in nrs[]
-            find_end(range, range + 9, nrs, nrs + 3, Twice{}),
+            find_end(range, range + 9, nrs, nrs + 3, twice),
             range + 9, ostream_iterator<size_t>{ cout, " " }
         );
         cout << '\n';
     }
-    /*
-        Displays:
-            foxtrot golf hotel india juliet kilo
-            4 6 8 10
-    */
+    //  Displays:
+    //      foxtrot golf hotel india juliet kilo
+    //      4 6 8 10
