@@ -5,14 +5,11 @@
     #include <iostream>
     using namespace std;
 
-    class CaseString
+    bool caseString(string const &first, string const &second)
     {
-        public:
-            bool operator()(string const &first, string const &second) const
-            {
-                return strcasecmp(first.c_str(), second.c_str()) < 0;
-            }
-    };
+        return strcasecmp(first.c_str(), second.c_str()) == 0;
+    }
+
     int main()
     {
         string range[] =
@@ -31,12 +28,10 @@
                 "bravo", "ECHO", "GOLF"
             };
 
-        inplace_merge(range2, range2 + 5, range2 + 8, CaseString{});
+        inplace_merge(range2, range2 + 5, range2 + 8, caseString);
         copy(range2, range2 + 8, ostream_iterator<string>{ cout, " " });
         cout << '\n';
     }
-    /*
-        Displays:
-            alpha bravo charley delta echo foxtrot golf
-            ALPHA bravo CHARLEY DELTA ECHO foxtrot GOLF hotel
-    */
+    //  Displays:
+    //      alpha bravo charley delta echo foxtrot golf
+    //      ALPHA bravo CHARLEY DELTA ECHO foxtrot GOLF hotel
