@@ -6,8 +6,8 @@
     class Insertable
     {
         public:
-            typedef int value_type;
-            typedef int const &const_reference;
+            using value_type = int;
+            using const_reference = int const &;
 
             void push_back(int const &)
             {}
