@@ -16,7 +16,7 @@ int main()
     if (not regex_search(target, results, re))
         return 1;
 //=
-    results.format(ostream_iterator<char>(cout, ""), string("$2"));
+    results.format(ostream_iterator<char>(cout, ""), "$2"s);
     cout << '\n';
 
     string reverse(results.format("$2 and $1"));
