@@ -1,4 +1,4 @@
-#include <iostream>     // don't forget the -pthread compiler option
+#include <iostream>
 #include <thread>
 #include <chrono>
 using namespace std;
