@@ -1,4 +1,4 @@
-#include <iostream>     // don't forget the -pthread compiler option
+#include <iostream>
 #include <thread>
 #include <chrono>
 using namespace std;
@@ -19,5 +19,6 @@ int main()
     this_thread::sleep_for(3s);
 
     thr.request_stop();
-    thr.join();
+
+    // thr.join() not required.
 }
